class Chef
  class Provider::FirewallInterface < Chef::Provider::LWRPBase
    include Firehol::Helpers

    provides :firewall_interface

    def whyrun_supported?
      true
    end

    attributes = %i(interface options policy protocol)
    action :create do
      firewall = {
        interface: new_resource.interface,
        options:   new_resource.options,
        policy:    new_resource.policy,
        type:      format_type("interface", new_resource.protocol)
      }

      interface = node["firewall"]["interfaces"][new_resource.common_name]
      if !interface || interface.symbolize_keys.slice(*attributes) != firewall
        converge_by("Update/create #{new_resource.common_name} interface") do
          node.normal["firewall"]["interfaces"][new_resource.common_name].tap do |details|
            firewall.keys.each do |key|
              details[key] = firewall[key]
            end
            details["rules"] = {} unless details["rules"]
          end

          firewall_resource = run_context.resource_collection.find(firewall: "firehol")
          raise "could not find a firewall resource" unless firewall_resource
          new_resource.notifies(:restart, firewall_resource, :delayed)
        end
      end
    end
  end
end
