class Chef
  class Provider::FirewallService < Chef::Provider::LWRPBase
    include Firehol::Helpers

    provides :firewall_service

    def whyrun_supported?
      true
    end

    attributes = %i(client_ports description server_ports)
    action :create do
      service = {
        client_ports: ports_to_s(new_resource.client_ports),
        description:  new_resource.description,
        server_ports: ports_to_s(new_resource.server_ports)
      }

      current_service = node["firewall"]["services"][new_resource.service_name]
      if !current_service || current_service.symbolize_keys.slice(*attributes) != service
        converge_by("Update/create #{new_resource.service_name} service") do
          service.keys.each do |key|
            node.normal["firewall"]["services"][new_resource.service_name][key] = service[key]
          end

          firewall_resource = run_context.resource_collection.find(firewall: "firehol")
          raise "could not find a firewall resource" unless firewall_resource
          new_resource.notifies(:restart, firewall_resource, :delayed)
        end
      end
    end
  end
end
